FORMAL_MARKERS = [
    "please", "kindly", "therefore", "however",
    "furthermore", "regarding", "respectfully",
    "do not", "does not", "cannot"
]

INFORMAL_MARKERS = [
    "hey", "hi", "yeah", "ok", "okay",
    "gonna", "wanna", "dont", "can't",
    "cool", "lol"
]


def formal_rule(text: str) -> int:
    """
    Returns:
        1 -> Formal
        0 -> Informal
    """
    t = text.lower()

    for m in INFORMAL_MARKERS:
        if m in t:
            return 0

    for m in FORMAL_MARKERS:
        if m in t:
            return 1

    # no strong signal
    return 0



import os
import joblib
from embeddings.vectorizer import build_vectorizer

# Get absolute path to project root
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

RAW_PATH = os.path.join(BASE_DIR, "raw.txt")
ARTIFACTS_DIR = os.path.join(BASE_DIR, "artifacts")
OUT_PATH = os.path.join(ARTIFACTS_DIR, "vectorizer.joblib")


def load_raw_text(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]


def main():
    texts = load_raw_text(RAW_PATH)

    vectorizer = build_vectorizer()
    vectorizer.fit(texts)

    # Ensure artifacts directory exists
    os.makedirs(ARTIFACTS_DIR, exist_ok=True)

    joblib.dump(vectorizer, OUT_PATH)
    print(f"Vectorizer fitted and saved to {OUT_PATH}")


if __name__ == "__main__":
    main()



PERSUASIVE_MARKERS = [
    "should", "must", "need to",
    "recommend", "strongly recommend",
    "suggest", "urge", "encourage",
    "it is better to", "you should",
    "we should", "i advise"
]

INFORMATIVE_MARKERS = [
    "explains", "describes", "reports",
    "according to", "is defined as",
    "refers to", "consists of"
]
PERSUASIVE_INTENT_VERBS = [
    "recommend", "suggest", "advise",
    "encourage", "urge"
]


def persuasive_rule(text: str) -> int:
    """
    Returns:
        1 -> Persuasive
        0 -> Informative
    """
    t = text.lower()

    # Strong persuasive intent
    for m in PERSUASIVE_MARKERS:
        if m in t:
            return 1

    # Strong informative framing
    for m in INFORMATIVE_MARKERS:
        if m in t:
            return 0

    # No strong signal
    return 0



import os
import joblib
from fusion.fused_classifier import FusedClassifier
from rules.formal_rules import formal_rule

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
MODEL_PATH = os.path.join(BASE_DIR, "artifacts", "formal_model.joblib")


def main():
    model = joblib.load(MODEL_PATH)

    # Lower alpha than questioning
    fused = FusedClassifier(
        model=model,
        rule_fn=formal_rule,
        alpha=0.4,
        threshold=0.5
    )

    tests = [
        "Please review the attached document.",
        "I kindly request your feedback.",
        "Hey, can you check this out?",
        "yeah this looks cool",
        "The report describes the methodology."
    ]

    for t in tests:
        pred = fused.predict(t)
        label = "Formal" if pred == 1 else "Informal"
        print(f"{label} → {t}")


if __name__ == "__main__":
    main()



import csv
import os
import re

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
RAW_PATH = os.path.join(BASE_DIR, "raw.txt")
OUT_PATH = os.path.join(BASE_DIR, "data", "questioning.csv")

QUESTION_WORDS = [
    "what", "why", "how", "when", "where",
    "who", "whom", "which", "is", "are",
    "do", "does", "did", "can", "could",
    "should", "would"
]


def load_raw_text(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]


def label_text(text):
    t = text.lower()

    if t.endswith("?"):
        return 1

    for qw in QUESTION_WORDS:
        if re.match(rf"^{qw}\b", t):
            return 1

    return 0

def load_extra_questions(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]

def main():
    texts = load_raw_text(RAW_PATH)

    # add synthetic questioning samples
    extra_path = os.path.join(BASE_DIR, "data", "questioning_extra.txt")
    extra_questions = load_extra_questions(extra_path)

    with open(OUT_PATH, "w", newline="", encoding="utf-8") as f:
        writer = csv.writer(f)
        writer.writerow(["text", "label"])

        for text in texts:
            writer.writerow([text, label_text(text)])

        # force class-1 presence
        for q in extra_questions:
            writer.writerow([q, 1])

    print(f"Questioning dataset written to {OUT_PATH}")


if __name__ == "__main__":
    main()



import csv
import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
RAW_PATH = os.path.join(BASE_DIR, "raw.txt")
OUT_PATH = os.path.join(BASE_DIR, "data", "formal.csv")

FORMAL_MARKERS = [
    "please", "kindly", "therefore", "however",
    "furthermore", "regarding", "respectfully",
    "cannot", "do not", "does not"
]

INFORMAL_MARKERS = [
    "hey", "hi", "yeah", "ok", "okay",
    "gonna", "wanna", "dont", "can't",
    "cool", "lol"
]


def load_raw_text(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]


def label_text(text):
    t = text.lower()

    for m in INFORMAL_MARKERS:
        if m in t:
            return 0

    for m in FORMAL_MARKERS:
        if m in t:
            return 1

    # default to formal (safer)
    return 1


def main():
    texts = load_raw_text(RAW_PATH)

    with open(OUT_PATH, "w", newline="", encoding="utf-8") as f:
        writer = csv.writer(f)
        writer.writerow(["text", "label"])

        for text in texts:
            writer.writerow([text, label_text(text)])

    print(f"Formal dataset written to {OUT_PATH}")


if __name__ == "__main__":
    main()



import os
import csv
import joblib
from models.narrative import NarrativeClassifier

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

DATA_PATH = os.path.join(BASE_DIR, "data", "narrative.csv")
VEC_PATH = os.path.join(BASE_DIR, "artifacts", "vectorizer.joblib")
OUT_PATH = os.path.join(BASE_DIR, "artifacts", "narrative_model.joblib")


def load_dataset(path):
    texts, labels = [], []
    with open(path, "r", encoding="utf-8") as f:
        reader = csv.DictReader(f)
        for row in reader:
            texts.append(row["text"])
            labels.append(int(row["label"]))
    return texts, labels


def main():
    texts, labels = load_dataset(DATA_PATH)
    vectorizer = joblib.load(VEC_PATH)

    model = NarrativeClassifier(vectorizer)
    model.fit(texts, labels)

    joblib.dump(model, OUT_PATH)
    print(f"Narrative model trained and saved to {OUT_PATH}")


if __name__ == "__main__":
    main()



import os
import joblib

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
MODEL_PATH = os.path.join(BASE_DIR, "artifacts", "assertive_model.joblib")


def main():
    model = joblib.load(MODEL_PATH)

    tests = [
        "You must complete this task today.",
        "If you don't mind, could you review this?",
        "Make sure the report is submitted.",
        "I think maybe we should wait."
    ]

    for t in tests:
        pred = model.predict(t)
        label = "Assertive" if pred == 1 else "Submissive"
        print(f"{label} → {t}")


if __name__ == "__main__":
    main()



import csv
import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
RAW_PATH = os.path.join(BASE_DIR, "raw.txt")
OUT_PATH = os.path.join(BASE_DIR, "data", "narrative.csv")

NARRATIVE_MARKERS = [
    "then", "after", "before", "when",
    "suddenly", "eventually", "once",
    "later", "earlier", "while"
]

EXPLANATORY_MARKERS = [
    "explains", "describes", "refers to",
    "defined as", "consists of",
    "is used to", "means that"
]


def load_raw_text(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]


def label_text(text):
    t = text.lower()

    for m in NARRATIVE_MARKERS:
        if m in t:
            return 1

    for m in EXPLANATORY_MARKERS:
        if m in t:
            return 0

    # default to explanatory (safer)
    return 0


def main():
    texts = load_raw_text(RAW_PATH)

    with open(OUT_PATH, "w", newline="", encoding="utf-8") as f:
        writer = csv.writer(f)
        writer.writerow(["text", "label"])

        for text in texts:
            writer.writerow([text, label_text(text)])

    print(f"Narrative dataset written to {OUT_PATH}")


if __name__ == "__main__":
    main()



import os
import joblib

from tone.fusion.fused_classifier import FusedClassifier

from tone.rules.persuasive_rules import (
    persuasive_rule,
    PERSUASIVE_INTENT_VERBS
)
from tone.rules.questioning_rules import questioning_rule
from tone.rules.formal_rules import formal_rule
from tone.rules.assertive_rules import (
    assertive_rule,
    ASSERTIVE_INTENT_VERBS
)
from tone.rules.authoritative_rules import (
    authoritative_rule,
    AUTHORITATIVE_INTENT_VERBS
)
from tone.rules.narrative_rules import narrative_rule
from tone.rules.negation import is_negated_intent


class ToneAnalyzer:
    """
    Unified API for tone analysis (v1)
    """

    def __init__(self, artifacts_path: str):
        if not os.path.isdir(artifacts_path):
            raise ValueError(f"Invalid artifacts path: {artifacts_path}")

        self.persuasive = self._load(
            artifacts_path,
            "persuasive_model.joblib",
            persuasive_rule,
            alpha=0.6,
            neg_fn=is_negated_intent,
            verbs=PERSUASIVE_INTENT_VERBS
        )

        self.questioning = self._load(
            artifacts_path,
            "questioning_model.joblib",
            questioning_rule,
            alpha=0.8
        )

        self.formal = self._load(
            artifacts_path,
            "formal_model.joblib",
            formal_rule,
            alpha=0.4
        )

        self.assertive = self._load(
            artifacts_path,
            "assertive_model.joblib",
            assertive_rule,
            alpha=0.5,
            neg_fn=is_negated_intent,
            verbs=ASSERTIVE_INTENT_VERBS
        )

        self.authoritative = self._load(
            artifacts_path,
            "authoritative_model.joblib",
            authoritative_rule,
            alpha=0.5,
            neg_fn=is_negated_intent,
            verbs=AUTHORITATIVE_INTENT_VERBS
        )

        self.narrative = self._load(
            artifacts_path,
            "narrative_model.joblib",
            narrative_rule,
            alpha=0.6
        )

    def _load(
        self,
        base_path,
        filename,
        rule_fn,
        alpha,
        neg_fn=None,
        verbs=None
    ):
        path = os.path.join(base_path, filename)
        if not os.path.isfile(path):
            raise FileNotFoundError(f"Missing model artifact: {path}")

        model = joblib.load(path)

        return FusedClassifier(
            model=model,
            rule_fn=rule_fn,
            alpha=alpha,
            negation_fn=neg_fn,
            intent_verbs=verbs
        )

    def analyze(self, text: str) -> dict:
        """
        Analyze input text across all tone axes.
        """
        return {
            "persuasive": bool(self.persuasive.predict(text)),
            "questioning": bool(self.questioning.predict(text)),
            "formal": bool(self.formal.predict(text)),
            "assertive": bool(self.assertive.predict(text)),
            "authoritative": bool(self.authoritative.predict(text)),
            "narrative": bool(self.narrative.predict(text)),
        }



import os
import joblib
from fusion.fused_classifier import FusedClassifier
from rules.assertive_rules import assertive_rule, ASSERTIVE_INTENT_VERBS
from rules.negation import is_negated_intent

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
MODEL_PATH = os.path.join(BASE_DIR, "artifacts", "assertive_model.joblib")


def main():
    model = joblib.load(MODEL_PATH)

    fused = FusedClassifier(
        model=model,
        rule_fn=assertive_rule,
        alpha=0.5,
        threshold=0.5,
        negation_fn=is_negated_intent,
        intent_verbs=ASSERTIVE_INTENT_VERBS
    )

    tests = [
        "You must complete this task today.",
        "Make sure the report is submitted.",
        "If you don't mind, could you review this?",
        "I think maybe we should wait.",
        "The document describes the process."
    ]

    for t in tests:
        pred = fused.predict(t)
        label = "Assertive" if pred == 1 else "Submissive"
        print(f"{label} → {t}")


if __name__ == "__main__":
    main()



from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.pipeline import FeatureUnion


def build_vectorizer():
    word_vectorizer = TfidfVectorizer(
        ngram_range=(1, 2),
        analyzer="word",
        lowercase=True,
        min_df=2,
        max_df=0.95
    )

    char_vectorizer = TfidfVectorizer(
        ngram_range=(3, 5),
        analyzer="char",
        lowercase=True,
        min_df=2,
        max_df=0.95
    )

    return FeatureUnion([
        ("word", word_vectorizer),
        ("char", char_vectorizer)
    ])



# persuasive
import csv
import os

# Resolve project root safely
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

RAW_PATH = os.path.join(BASE_DIR, "raw.txt")
OUT_PATH = os.path.join(BASE_DIR, "data", "persuasive.csv")

PERSUASIVE_MARKERS = [
    "should",
    "must",
    "recommend",
    "suggest",
    "urge",
    "need to",
    "strongly believe",
    "encourage"
]


def load_raw_text(path):
    with open(path, "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip()]


def label_text(text):
    t = text.lower()
    for marker in PERSUASIVE_MARKERS:
        if marker in t:
            return 1
    return 0


def main():
    texts = load_raw_text(RAW_PATH)

    with open(OUT_PATH, "w", newline="", encoding="utf-8") as f:
        writer = csv.writer(f)
        writer.writerow(["text", "label"])

        for text in texts:
            writer.writerow([text, label_text(text)])

    print(f"Dataset written to {OUT_PATH}")


if __name__ == "__main__":
    main()



from sklearn.linear_model import LogisticRegression


class AssertiveClassifier:
    def __init__(self, vectorizer, threshold=0.5):
        self.vectorizer = vectorizer
        self.model = LogisticRegression(max_iter=1000)
        self.threshold = threshold

    def fit(self, texts, labels):
        X = self.vectorizer.transform(texts)
        self.model.fit(X, labels)

    def predict(self, text):
        X = self.vectorizer.transform([text])
        prob = self.model.predict_proba(X)[0][1]
        return int(prob >= self.threshold)
